@@ -1,10 +1,12 @@
+// requires
+// * stdio.h
+// * gmp.h
+// * fops.h
+// * symtab.h
+// * field.h
 #ifndef PAIRING_H
 #define PAIRING_H
 
-#include <stdio.h>
-#include "curve.h"
-#include "fops.h"
-
 struct pairing_s {
     mpz_t r; //order of G1, G2, GT
     field_t Zr; //the field Z_r
@@ -22,6 +24,7 @@ struct pairing_s {
     //char *id;
     void (*clear_func)(struct pairing_s *);
     void *data;
+    symtab_t option;
 };
 
 typedef struct pairing_s pairing_t[1];
@@ -30,7 +33,7 @@ typedef struct pairing_s *pairing_ptr;
 /*@manual pairing_init
 TODO
 */
-void pairing_init_inp_generic(pairing_t pairing, fetch_ops_t *fops, void *ctx);
+void pairing_init_inp_generic(pairing_t pairing, fetch_ops_t fops, void *ctx);
 
 /*@manual pairing_init
 Read in pairing parameters from array of characters ''buf'' of length ''len''
